@@ -106,6 +106,11 @@ use hvcg_governance_openapi_catholic_polity::{
     GetDioceseByIdResponse,
     GetDiocesesResponse,
     UpdateDioceseResponse,
+    AddInstituteResponse,
+    DeleteInstituteResponse,
+    GetInstituteByIdResponse,
+    GetInstitutesResponse,
+    UpdateInstituteResponse,
     AddParishResponse,
     DeleteParishResponse,
     GetParishByIdResponse,
@@ -243,6 +248,64 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         Err("Generic failuare".into())
     }
 
+    /// Add new institute
+    async fn add_institute(
+        &self,
+        institute: models::Institute,
+        context: &C) -> Result<AddInstituteResponse, ApiError>
+    {
+        let context = context.clone();
+        info!("add_institute({:?}) - X-Span-ID: {:?}", institute, context.get().0.clone());
+        Err("Generic failuare".into())
+    }
+
+    /// Delete institute by ID
+    async fn delete_institute(
+        &self,
+        id: uuid::Uuid,
+        context: &C) -> Result<DeleteInstituteResponse, ApiError>
+    {
+        let context = context.clone();
+        info!("delete_institute({:?}) - X-Span-ID: {:?}", id, context.get().0.clone());
+        Err("Generic failuare".into())
+    }
+
+    /// Find institute by ID
+    async fn get_institute_by_id(
+        &self,
+        id: uuid::Uuid,
+        context: &C) -> Result<GetInstituteByIdResponse, ApiError>
+    {
+        let context = context.clone();
+        info!("get_institute_by_id({:?}) - X-Span-ID: {:?}", id, context.get().0.clone());
+        Err("Generic failuare".into())
+    }
+
+    /// Get institutes
+    async fn get_institutes(
+        &self,
+        name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
+        context: &C) -> Result<GetInstitutesResponse, ApiError>
+    {
+        let context = context.clone();
+        info!("get_institutes({:?}, {:?}, {:?}) - X-Span-ID: {:?}", name, offset, count, context.get().0.clone());
+        Err("Generic failuare".into())
+    }
+
+    /// Update an existing institute
+    async fn update_institute(
+        &self,
+        id: uuid::Uuid,
+        institute: models::Institute,
+        context: &C) -> Result<UpdateInstituteResponse, ApiError>
+    {
+        let context = context.clone();
+        info!("update_institute({:?}, {:?}) - X-Span-ID: {:?}", id, institute, context.get().0.clone());
+        Err("Generic failuare".into())
+    }
+
     /// Add new parish
     async fn add_parish(
         &self,
