@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.4.0";
+pub const API_VERSION: &'static str = "0.5.0";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -150,6 +150,75 @@ pub enum UpdateDioceseResponse {
     ValidationException
 }
 
+#[derive(Debug, PartialEq, Serialize, Deserialize)]
+#[must_use]
+pub enum AddInstituteResponse {
+    /// successful operation
+    SuccessfulOperation
+    (models::Institute)
+    ,
+    /// Invalid input
+    InvalidInput
+}
+
+#[derive(Debug, PartialEq, Serialize, Deserialize)]
+#[must_use]
+pub enum DeleteInstituteResponse {
+    /// successful operation
+    SuccessfulOperation
+    ,
+    /// Invalid ID supplied
+    InvalidIDSupplied
+    ,
+    /// Institute not found
+    InstituteNotFound
+}
+
+#[derive(Debug, PartialEq, Serialize, Deserialize)]
+#[must_use]
+pub enum GetInstituteByIdResponse {
+    /// successful operation
+    SuccessfulOperation
+    (models::Institute)
+    ,
+    /// Invalid ID supplied
+    InvalidIDSupplied
+    ,
+    /// Institute not found
+    InstituteNotFound
+}
+
+#[derive(Debug, PartialEq, Serialize, Deserialize)]
+#[must_use]
+pub enum GetInstitutesResponse {
+    /// successful operation
+    SuccessfulOperation
+    (models::InstituteCollection)
+    ,
+    /// Invalid ID supplied
+    InvalidIDSupplied
+    ,
+    /// Institute not found
+    InstituteNotFound
+}
+
+#[derive(Debug, PartialEq, Serialize, Deserialize)]
+#[must_use]
+pub enum UpdateInstituteResponse {
+    /// successful operation
+    SuccessfulOperation
+    (models::Institute)
+    ,
+    /// Invalid ID supplied
+    InvalidIDSupplied
+    ,
+    /// Institute not found
+    InstituteNotFound
+    ,
+    /// Validation exception
+    ValidationException
+}
+
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
 pub enum AddParishResponse {
@@ -364,6 +433,39 @@ pub trait Api<C: Send + Sync> {
         diocese: models::Diocese,
         context: &C) -> Result<UpdateDioceseResponse, ApiError>;
 
+    /// Add new institute
+    async fn add_institute(
+        &self,
+        institute: models::Institute,
+        context: &C) -> Result<AddInstituteResponse, ApiError>;
+
+    /// Delete institute by ID
+    async fn delete_institute(
+        &self,
+        id: uuid::Uuid,
+        context: &C) -> Result<DeleteInstituteResponse, ApiError>;
+
+    /// Find institute by ID
+    async fn get_institute_by_id(
+        &self,
+        id: uuid::Uuid,
+        context: &C) -> Result<GetInstituteByIdResponse, ApiError>;
+
+    /// Get institutes
+    async fn get_institutes(
+        &self,
+        name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
+        context: &C) -> Result<GetInstitutesResponse, ApiError>;
+
+    /// Update an existing institute
+    async fn update_institute(
+        &self,
+        id: uuid::Uuid,
+        institute: models::Institute,
+        context: &C) -> Result<UpdateInstituteResponse, ApiError>;
+
     /// Add new parish
     async fn add_parish(
         &self,
@@ -512,6 +614,39 @@ pub trait ApiNoContext<C: Send + Sync> {
         diocese: models::Diocese,
         ) -> Result<UpdateDioceseResponse, ApiError>;
 
+    /// Add new institute
+    async fn add_institute(
+        &self,
+        institute: models::Institute,
+        ) -> Result<AddInstituteResponse, ApiError>;
+
+    /// Delete institute by ID
+    async fn delete_institute(
+        &self,
+        id: uuid::Uuid,
+        ) -> Result<DeleteInstituteResponse, ApiError>;
+
+    /// Find institute by ID
+    async fn get_institute_by_id(
+        &self,
+        id: uuid::Uuid,
+        ) -> Result<GetInstituteByIdResponse, ApiError>;
+
+    /// Get institutes
+    async fn get_institutes(
+        &self,
+        name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
+        ) -> Result<GetInstitutesResponse, ApiError>;
+
+    /// Update an existing institute
+    async fn update_institute(
+        &self,
+        id: uuid::Uuid,
+        institute: models::Institute,
+        ) -> Result<UpdateInstituteResponse, ApiError>;
+
     /// Add new parish
     async fn add_parish(
         &self,
@@ -715,6 +850,59 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         self.api().update_diocese(id, diocese, &context).await
     }
 
+    /// Add new institute
+    async fn add_institute(
+        &self,
+        institute: models::Institute,
+        ) -> Result<AddInstituteResponse, ApiError>
+    {
+        let context = self.context().clone();
+        self.api().add_institute(institute, &context).await
+    }
+
+    /// Delete institute by ID
+    async fn delete_institute(
+        &self,
+        id: uuid::Uuid,
+        ) -> Result<DeleteInstituteResponse, ApiError>
+    {
+        let context = self.context().clone();
+        self.api().delete_institute(id, &context).await
+    }
+
+    /// Find institute by ID
+    async fn get_institute_by_id(
+        &self,
+        id: uuid::Uuid,
+        ) -> Result<GetInstituteByIdResponse, ApiError>
+    {
+        let context = self.context().clone();
+        self.api().get_institute_by_id(id, &context).await
+    }
+
+    /// Get institutes
+    async fn get_institutes(
+        &self,
+        name: Option<String>,
+        offset: Option<i32>,
+        count: Option<i32>,
+        ) -> Result<GetInstitutesResponse, ApiError>
+    {
+        let context = self.context().clone();
+        self.api().get_institutes(name, offset, count, &context).await
+    }
+
+    /// Update an existing institute
+    async fn update_institute(
+        &self,
+        id: uuid::Uuid,
+        institute: models::Institute,
+        ) -> Result<UpdateInstituteResponse, ApiError>
+    {
+        let context = self.context().clone();
+        self.api().update_institute(id, institute, &context).await
+    }
+
     /// Add new parish
     async fn add_parish(
         &self,
