@@ -57,18 +57,29 @@ pub struct Deanery {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationAddress")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_address: Option<String>,
+
+    #[serde(rename = "locationName")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_name: Option<String>,
+
     #[serde(rename = "personInCharge")]
-    pub person_in_charge: String,
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub person_in_charge: Option<String>,
 
 }
 
 impl Deanery {
-    pub fn new(diocese: models::Diocese, name: String, person_in_charge: String, ) -> Deanery {
+    pub fn new(diocese: models::Diocese, name: String, ) -> Deanery {
         Deanery {
             diocese: diocese,
             id: None,
             name: name,
-            person_in_charge: person_in_charge,
+            location_address: None,
+            location_name: None,
+            person_in_charge: None,
         }
     }
 }
@@ -88,8 +99,22 @@ impl std::string::ToString for Deanery {
         params.push(self.name.to_string());
 
 
-        params.push("personInCharge".to_string());
-        params.push(self.person_in_charge.to_string());
+        if let Some(ref location_address) = self.location_address {
+            params.push("locationAddress".to_string());
+            params.push(location_address.to_string());
+        }
+
+
+        if let Some(ref location_name) = self.location_name {
+            params.push("locationName".to_string());
+            params.push(location_name.to_string());
+        }
+
+
+        if let Some(ref person_in_charge) = self.person_in_charge {
+            params.push("personInCharge".to_string());
+            params.push(person_in_charge.to_string());
+        }
 
         params.join(",").to_string()
     }
@@ -108,6 +133,8 @@ impl std::str::FromStr for Deanery {
             pub diocese: Vec<models::Diocese>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_address: Vec<String>,
+            pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
         }
 
@@ -128,6 +155,8 @@ impl std::str::FromStr for Deanery {
                     "diocese" => intermediate_rep.diocese.push(<models::Diocese as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing Deanery".to_string())
                 }
@@ -142,7 +171,9 @@ impl std::str::FromStr for Deanery {
             diocese: intermediate_rep.diocese.into_iter().next().ok_or("diocese missing in Deanery".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Deanery".to_string())?,
-            person_in_charge: intermediate_rep.person_in_charge.into_iter().next().ok_or("personInCharge missing in Deanery".to_string())?,
+            location_address: intermediate_rep.location_address.into_iter().next(),
+            location_name: intermediate_rep.location_name.into_iter().next(),
+            person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
         })
     }
 }
@@ -325,18 +356,29 @@ pub struct Diocese {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationAddress")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_address: Option<String>,
+
+    #[serde(rename = "locationName")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_name: Option<String>,
+
     #[serde(rename = "personInCharge")]
-    pub person_in_charge: String,
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub person_in_charge: Option<String>,
 
 }
 
 impl Diocese {
-    pub fn new(province: models::Province, name: String, person_in_charge: String, ) -> Diocese {
+    pub fn new(province: models::Province, name: String, ) -> Diocese {
         Diocese {
             province: province,
             id: None,
             name: name,
-            person_in_charge: person_in_charge,
+            location_address: None,
+            location_name: None,
+            person_in_charge: None,
         }
     }
 }
@@ -356,8 +398,22 @@ impl std::string::ToString for Diocese {
         params.push(self.name.to_string());
 
 
-        params.push("personInCharge".to_string());
-        params.push(self.person_in_charge.to_string());
+        if let Some(ref location_address) = self.location_address {
+            params.push("locationAddress".to_string());
+            params.push(location_address.to_string());
+        }
+
+
+        if let Some(ref location_name) = self.location_name {
+            params.push("locationName".to_string());
+            params.push(location_name.to_string());
+        }
+
+
+        if let Some(ref person_in_charge) = self.person_in_charge {
+            params.push("personInCharge".to_string());
+            params.push(person_in_charge.to_string());
+        }
 
         params.join(",").to_string()
     }
@@ -376,6 +432,8 @@ impl std::str::FromStr for Diocese {
             pub province: Vec<models::Province>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_address: Vec<String>,
+            pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
         }
 
@@ -396,6 +454,8 @@ impl std::str::FromStr for Diocese {
                     "province" => intermediate_rep.province.push(<models::Province as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing Diocese".to_string())
                 }
@@ -410,7 +470,9 @@ impl std::str::FromStr for Diocese {
             province: intermediate_rep.province.into_iter().next().ok_or("province missing in Diocese".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Diocese".to_string())?,
-            person_in_charge: intermediate_rep.person_in_charge.into_iter().next().ok_or("personInCharge missing in Diocese".to_string())?,
+            location_address: intermediate_rep.location_address.into_iter().next(),
+            location_name: intermediate_rep.location_name.into_iter().next(),
+            person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
         })
     }
 }
@@ -579,6 +641,295 @@ impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderVal
 }
 
 
+#[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
+pub struct Institute {
+    #[serde(rename = "id")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub id: Option<uuid::Uuid>,
+
+    #[serde(rename = "name")]
+    pub name: String,
+
+    #[serde(rename = "locationAddress")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_address: Option<String>,
+
+    #[serde(rename = "locationName")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_name: Option<String>,
+
+    #[serde(rename = "personInCharge")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub person_in_charge: Option<String>,
+
+}
+
+impl Institute {
+    pub fn new(name: String, ) -> Institute {
+        Institute {
+            id: None,
+            name: name,
+            location_address: None,
+            location_name: None,
+            person_in_charge: None,
+        }
+    }
+}
+
+/// Converts the Institute value to the Query Parameters representation (style=form, explode=false)
+/// specified in https://swagger.io/docs/specification/serialization/
+/// Should be implemented in a serde serializer
+impl std::string::ToString for Institute {
+    fn to_string(&self) -> String {
+        let mut params: Vec<String> = vec![];
+        // Skipping id in query parameter serialization
+
+
+        params.push("name".to_string());
+        params.push(self.name.to_string());
+
+
+        if let Some(ref location_address) = self.location_address {
+            params.push("locationAddress".to_string());
+            params.push(location_address.to_string());
+        }
+
+
+        if let Some(ref location_name) = self.location_name {
+            params.push("locationName".to_string());
+            params.push(location_name.to_string());
+        }
+
+
+        if let Some(ref person_in_charge) = self.person_in_charge {
+            params.push("personInCharge".to_string());
+            params.push(person_in_charge.to_string());
+        }
+
+        params.join(",").to_string()
+    }
+}
+
+/// Converts Query Parameters representation (style=form, explode=false) to a Institute value
+/// as specified in https://swagger.io/docs/specification/serialization/
+/// Should be implemented in a serde deserializer
+impl std::str::FromStr for Institute {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        #[derive(Default)]
+        // An intermediate representation of the struct to use for parsing.
+        struct IntermediateRep {
+            pub id: Vec<uuid::Uuid>,
+            pub name: Vec<String>,
+            pub location_address: Vec<String>,
+            pub location_name: Vec<String>,
+            pub person_in_charge: Vec<String>,
+        }
+
+        let mut intermediate_rep = IntermediateRep::default();
+
+        // Parse into intermediate representation
+        let mut string_iter = s.split(',').into_iter();
+        let mut key_result = string_iter.next();
+
+        while key_result.is_some() {
+            let val = match string_iter.next() {
+                Some(x) => x,
+                None => return std::result::Result::Err("Missing value while parsing Institute".to_string())
+            };
+
+            if let Some(key) = key_result {
+                match key {
+                    "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    _ => return std::result::Result::Err("Unexpected key while parsing Institute".to_string())
+                }
+            }
+
+            // Get the next key
+            key_result = string_iter.next();
+        }
+
+        // Use the intermediate representation to return the struct
+        std::result::Result::Ok(Institute {
+            id: intermediate_rep.id.into_iter().next(),
+            name: intermediate_rep.name.into_iter().next().ok_or("name missing in Institute".to_string())?,
+            location_address: intermediate_rep.location_address.into_iter().next(),
+            location_name: intermediate_rep.location_name.into_iter().next(),
+            person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
+        })
+    }
+}
+
+// Methods for converting between header::IntoHeaderValue<Institute> and hyper::header::HeaderValue
+
+#[cfg(any(feature = "client", feature = "server"))]
+impl std::convert::TryFrom<header::IntoHeaderValue<Institute>> for hyper::header::HeaderValue {
+    type Error = String;
+
+    fn try_from(hdr_value: header::IntoHeaderValue<Institute>) -> std::result::Result<Self, Self::Error> {
+        let hdr_value = hdr_value.to_string();
+        match hyper::header::HeaderValue::from_str(&hdr_value) {
+             std::result::Result::Ok(value) => std::result::Result::Ok(value),
+             std::result::Result::Err(e) => std::result::Result::Err(
+                 format!("Invalid header value for Institute - value: {} is invalid {}",
+                     hdr_value, e))
+        }
+    }
+}
+
+#[cfg(any(feature = "client", feature = "server"))]
+impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderValue<Institute> {
+    type Error = String;
+
+    fn try_from(hdr_value: hyper::header::HeaderValue) -> std::result::Result<Self, Self::Error> {
+        match hdr_value.to_str() {
+             std::result::Result::Ok(value) => {
+                    match <Institute as std::str::FromStr>::from_str(value) {
+                        std::result::Result::Ok(value) => std::result::Result::Ok(header::IntoHeaderValue(value)),
+                        std::result::Result::Err(err) => std::result::Result::Err(
+                            format!("Unable to convert header value '{}' into Institute - {}",
+                                value, err))
+                    }
+             },
+             std::result::Result::Err(e) => std::result::Result::Err(
+                 format!("Unable to convert header: {:?} to string: {}",
+                     hdr_value, e))
+        }
+    }
+}
+
+
+#[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
+pub struct InstituteCollection {
+    #[serde(rename = "institutes")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub institutes: Option<Vec<models::Institute>>,
+
+    #[serde(rename = "hasMore")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub has_more: Option<bool>,
+
+}
+
+impl InstituteCollection {
+    pub fn new() -> InstituteCollection {
+        InstituteCollection {
+            institutes: None,
+            has_more: None,
+        }
+    }
+}
+
+/// Converts the InstituteCollection value to the Query Parameters representation (style=form, explode=false)
+/// specified in https://swagger.io/docs/specification/serialization/
+/// Should be implemented in a serde serializer
+impl std::string::ToString for InstituteCollection {
+    fn to_string(&self) -> String {
+        let mut params: Vec<String> = vec![];
+        // Skipping institutes in query parameter serialization
+
+
+        if let Some(ref has_more) = self.has_more {
+            params.push("hasMore".to_string());
+            params.push(has_more.to_string());
+        }
+
+        params.join(",").to_string()
+    }
+}
+
+/// Converts Query Parameters representation (style=form, explode=false) to a InstituteCollection value
+/// as specified in https://swagger.io/docs/specification/serialization/
+/// Should be implemented in a serde deserializer
+impl std::str::FromStr for InstituteCollection {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        #[derive(Default)]
+        // An intermediate representation of the struct to use for parsing.
+        struct IntermediateRep {
+            pub institutes: Vec<Vec<models::Institute>>,
+            pub has_more: Vec<bool>,
+        }
+
+        let mut intermediate_rep = IntermediateRep::default();
+
+        // Parse into intermediate representation
+        let mut string_iter = s.split(',').into_iter();
+        let mut key_result = string_iter.next();
+
+        while key_result.is_some() {
+            let val = match string_iter.next() {
+                Some(x) => x,
+                None => return std::result::Result::Err("Missing value while parsing InstituteCollection".to_string())
+            };
+
+            if let Some(key) = key_result {
+                match key {
+                    "institutes" => return std::result::Result::Err("Parsing a container in this style is not supported in InstituteCollection".to_string()),
+                    "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    _ => return std::result::Result::Err("Unexpected key while parsing InstituteCollection".to_string())
+                }
+            }
+
+            // Get the next key
+            key_result = string_iter.next();
+        }
+
+        // Use the intermediate representation to return the struct
+        std::result::Result::Ok(InstituteCollection {
+            institutes: intermediate_rep.institutes.into_iter().next(),
+            has_more: intermediate_rep.has_more.into_iter().next(),
+        })
+    }
+}
+
+// Methods for converting between header::IntoHeaderValue<InstituteCollection> and hyper::header::HeaderValue
+
+#[cfg(any(feature = "client", feature = "server"))]
+impl std::convert::TryFrom<header::IntoHeaderValue<InstituteCollection>> for hyper::header::HeaderValue {
+    type Error = String;
+
+    fn try_from(hdr_value: header::IntoHeaderValue<InstituteCollection>) -> std::result::Result<Self, Self::Error> {
+        let hdr_value = hdr_value.to_string();
+        match hyper::header::HeaderValue::from_str(&hdr_value) {
+             std::result::Result::Ok(value) => std::result::Result::Ok(value),
+             std::result::Result::Err(e) => std::result::Result::Err(
+                 format!("Invalid header value for InstituteCollection - value: {} is invalid {}",
+                     hdr_value, e))
+        }
+    }
+}
+
+#[cfg(any(feature = "client", feature = "server"))]
+impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderValue<InstituteCollection> {
+    type Error = String;
+
+    fn try_from(hdr_value: hyper::header::HeaderValue) -> std::result::Result<Self, Self::Error> {
+        match hdr_value.to_str() {
+             std::result::Result::Ok(value) => {
+                    match <InstituteCollection as std::str::FromStr>::from_str(value) {
+                        std::result::Result::Ok(value) => std::result::Result::Ok(header::IntoHeaderValue(value)),
+                        std::result::Result::Err(err) => std::result::Result::Err(
+                            format!("Unable to convert header value '{}' into InstituteCollection - {}",
+                                value, err))
+                    }
+             },
+             std::result::Result::Err(e) => std::result::Result::Err(
+                 format!("Unable to convert header: {:?} to string: {}",
+                     hdr_value, e))
+        }
+    }
+}
+
+
 #[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
 pub struct Parish {
@@ -592,18 +943,29 @@ pub struct Parish {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationAddress")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_address: Option<String>,
+
+    #[serde(rename = "locationName")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_name: Option<String>,
+
     #[serde(rename = "personInCharge")]
-    pub person_in_charge: String,
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub person_in_charge: Option<String>,
 
 }
 
 impl Parish {
-    pub fn new(deanery: models::Deanery, name: String, person_in_charge: String, ) -> Parish {
+    pub fn new(deanery: models::Deanery, name: String, ) -> Parish {
         Parish {
             deanery: deanery,
             id: None,
             name: name,
-            person_in_charge: person_in_charge,
+            location_address: None,
+            location_name: None,
+            person_in_charge: None,
         }
     }
 }
@@ -623,8 +985,22 @@ impl std::string::ToString for Parish {
         params.push(self.name.to_string());
 
 
-        params.push("personInCharge".to_string());
-        params.push(self.person_in_charge.to_string());
+        if let Some(ref location_address) = self.location_address {
+            params.push("locationAddress".to_string());
+            params.push(location_address.to_string());
+        }
+
+
+        if let Some(ref location_name) = self.location_name {
+            params.push("locationName".to_string());
+            params.push(location_name.to_string());
+        }
+
+
+        if let Some(ref person_in_charge) = self.person_in_charge {
+            params.push("personInCharge".to_string());
+            params.push(person_in_charge.to_string());
+        }
 
         params.join(",").to_string()
     }
@@ -643,6 +1019,8 @@ impl std::str::FromStr for Parish {
             pub deanery: Vec<models::Deanery>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_address: Vec<String>,
+            pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
         }
 
@@ -663,6 +1041,8 @@ impl std::str::FromStr for Parish {
                     "deanery" => intermediate_rep.deanery.push(<models::Deanery as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing Parish".to_string())
                 }
@@ -677,7 +1057,9 @@ impl std::str::FromStr for Parish {
             deanery: intermediate_rep.deanery.into_iter().next().ok_or("deanery missing in Parish".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Parish".to_string())?,
-            person_in_charge: intermediate_rep.person_in_charge.into_iter().next().ok_or("personInCharge missing in Parish".to_string())?,
+            location_address: intermediate_rep.location_address.into_iter().next(),
+            location_name: intermediate_rep.location_name.into_iter().next(),
+            person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
         })
     }
 }
@@ -856,17 +1238,28 @@ pub struct Polity {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationAddress")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_address: Option<String>,
+
+    #[serde(rename = "locationName")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_name: Option<String>,
+
     #[serde(rename = "personInCharge")]
-    pub person_in_charge: String,
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub person_in_charge: Option<String>,
 
 }
 
 impl Polity {
-    pub fn new(name: String, person_in_charge: String, ) -> Polity {
+    pub fn new(name: String, ) -> Polity {
         Polity {
             id: None,
             name: name,
-            person_in_charge: person_in_charge,
+            location_address: None,
+            location_name: None,
+            person_in_charge: None,
         }
     }
 }
@@ -884,8 +1277,22 @@ impl std::string::ToString for Polity {
         params.push(self.name.to_string());
 
 
-        params.push("personInCharge".to_string());
-        params.push(self.person_in_charge.to_string());
+        if let Some(ref location_address) = self.location_address {
+            params.push("locationAddress".to_string());
+            params.push(location_address.to_string());
+        }
+
+
+        if let Some(ref location_name) = self.location_name {
+            params.push("locationName".to_string());
+            params.push(location_name.to_string());
+        }
+
+
+        if let Some(ref person_in_charge) = self.person_in_charge {
+            params.push("personInCharge".to_string());
+            params.push(person_in_charge.to_string());
+        }
 
         params.join(",").to_string()
     }
@@ -903,6 +1310,8 @@ impl std::str::FromStr for Polity {
         struct IntermediateRep {
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_address: Vec<String>,
+            pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
         }
 
@@ -922,6 +1331,8 @@ impl std::str::FromStr for Polity {
                 match key {
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing Polity".to_string())
                 }
@@ -935,7 +1346,9 @@ impl std::str::FromStr for Polity {
         std::result::Result::Ok(Polity {
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Polity".to_string())?,
-            person_in_charge: intermediate_rep.person_in_charge.into_iter().next().ok_or("personInCharge missing in Polity".to_string())?,
+            location_address: intermediate_rep.location_address.into_iter().next(),
+            location_name: intermediate_rep.location_name.into_iter().next(),
+            person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
         })
     }
 }
@@ -992,18 +1405,29 @@ pub struct Province {
     #[serde(rename = "name")]
     pub name: String,
 
+    #[serde(rename = "locationAddress")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_address: Option<String>,
+
+    #[serde(rename = "locationName")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub location_name: Option<String>,
+
     #[serde(rename = "personInCharge")]
-    pub person_in_charge: String,
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub person_in_charge: Option<String>,
 
 }
 
 impl Province {
-    pub fn new(code: models::Code, name: String, person_in_charge: String, ) -> Province {
+    pub fn new(code: models::Code, name: String, ) -> Province {
         Province {
             code: code,
             id: None,
             name: name,
-            person_in_charge: person_in_charge,
+            location_address: None,
+            location_name: None,
+            person_in_charge: None,
         }
     }
 }
@@ -1023,8 +1447,22 @@ impl std::string::ToString for Province {
         params.push(self.name.to_string());
 
 
-        params.push("personInCharge".to_string());
-        params.push(self.person_in_charge.to_string());
+        if let Some(ref location_address) = self.location_address {
+            params.push("locationAddress".to_string());
+            params.push(location_address.to_string());
+        }
+
+
+        if let Some(ref location_name) = self.location_name {
+            params.push("locationName".to_string());
+            params.push(location_name.to_string());
+        }
+
+
+        if let Some(ref person_in_charge) = self.person_in_charge {
+            params.push("personInCharge".to_string());
+            params.push(person_in_charge.to_string());
+        }
 
         params.join(",").to_string()
     }
@@ -1043,6 +1481,8 @@ impl std::str::FromStr for Province {
             pub code: Vec<models::Code>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
+            pub location_address: Vec<String>,
+            pub location_name: Vec<String>,
             pub person_in_charge: Vec<String>,
         }
 
@@ -1063,6 +1503,8 @@ impl std::str::FromStr for Province {
                     "code" => intermediate_rep.code.push(<models::Code as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationAddress" => intermediate_rep.location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "locationName" => intermediate_rep.location_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing Province".to_string())
                 }
@@ -1077,7 +1519,9 @@ impl std::str::FromStr for Province {
             code: intermediate_rep.code.into_iter().next().ok_or("code missing in Province".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Province".to_string())?,
-            person_in_charge: intermediate_rep.person_in_charge.into_iter().next().ok_or("personInCharge missing in Province".to_string())?,
+            location_address: intermediate_rep.location_address.into_iter().next(),
+            location_name: intermediate_rep.location_name.into_iter().next(),
+            person_in_charge: intermediate_rep.person_in_charge.into_iter().next(),
         })
     }
 }
@@ -1124,9 +1568,9 @@ impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderVal
 #[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
 pub struct ProvinceCollection {
-    #[serde(rename = "parishes")]
+    #[serde(rename = "provinces")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub parishes: Option<Vec<models::Province>>,
+    pub provinces: Option<Vec<models::Province>>,
 
     #[serde(rename = "hasMore")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -1137,7 +1581,7 @@ pub struct ProvinceCollection {
 impl ProvinceCollection {
     pub fn new() -> ProvinceCollection {
         ProvinceCollection {
-            parishes: None,
+            provinces: None,
             has_more: None,
         }
     }
@@ -1149,7 +1593,7 @@ impl ProvinceCollection {
 impl std::string::ToString for ProvinceCollection {
     fn to_string(&self) -> String {
         let mut params: Vec<String> = vec![];
-        // Skipping parishes in query parameter serialization
+        // Skipping provinces in query parameter serialization
 
 
         if let Some(ref has_more) = self.has_more {
@@ -1171,7 +1615,7 @@ impl std::str::FromStr for ProvinceCollection {
         #[derive(Default)]
         // An intermediate representation of the struct to use for parsing.
         struct IntermediateRep {
-            pub parishes: Vec<Vec<models::Province>>,
+            pub provinces: Vec<Vec<models::Province>>,
             pub has_more: Vec<bool>,
         }
 
@@ -1189,7 +1633,7 @@ impl std::str::FromStr for ProvinceCollection {
 
             if let Some(key) = key_result {
                 match key {
-                    "parishes" => return std::result::Result::Err("Parsing a container in this style is not supported in ProvinceCollection".to_string()),
+                    "provinces" => return std::result::Result::Err("Parsing a container in this style is not supported in ProvinceCollection".to_string()),
                     "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing ProvinceCollection".to_string())
                 }
@@ -1201,7 +1645,7 @@ impl std::str::FromStr for ProvinceCollection {
 
         // Use the intermediate representation to return the struct
         std::result::Result::Ok(ProvinceCollection {
-            parishes: intermediate_rep.parishes.into_iter().next(),
+            provinces: intermediate_rep.provinces.into_iter().next(),
             has_more: intermediate_rep.has_more.into_iter().next(),
         })
     }
